==> netdude_0.3.3.orig.tar.gz: netdude-0.3.3/src/callbacks.h <==
#include <gtk/gtk.h>
#include <netdude/nd_packet.h>

void
on_filesel_ok_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_filesel_cancel_clicked              (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_toplevel_delete_event               (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_confirm_yes_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_confirm_no_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_confirm_cancel_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_trace_list_select_row             (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_trace_list_row_move               (GtkCList        *clist,
                                        gint             arg1,
                                        gint             arg2,
                                        gpointer         user_data);

gboolean
on_trace_list_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_trace_list_select_row             (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_trace_list_unselect_row           (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_trace_list_end_selection          (GtkCList        *clist,
                                        gpointer         user_data);

void
on_trace_list_select_all             (GtkCList        *clist,
                                        gpointer         user_data);

void
on_trace_list_unselect_all           (GtkCList        *clist,
                                        gpointer         user_data);

void
on_trace_list_size_allocate          (GtkWidget       *widget,
                                        GtkAllocation   *allocation,
                                        gpointer         user_data);

gboolean
on_trace_list_motion_notify_event    (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

gboolean
on_trace_list_leave_notify_event     (GtkWidget       *widget,
                                        GdkEventCrossing *event,
                                        gpointer         user_data);

gboolean
on_trace_list_key_press_event        (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_packet_hide_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_show_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_cut_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_copy_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_paste_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_unselect_all_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_select_all_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_delete_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_menubar_button_press_event          (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_about_okay_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_preferences_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_pref_ok_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_pref_cancel_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_pref_apply_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_trace_win_bar_button_release_event  (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_plugin_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_pref_tcpdump_loc_browse_button_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_tcpdump_error_okay_button_clicked   (GtkButton       *button,
                                        gpointer         user_data);


gboolean
on_splash_window_button_press_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_recent_item0_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_recent_item1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_recent_item2_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_recent_item3_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_recent_item4_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about_plugin_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about_proto_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_trace_close_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_traces_notebook_switch_page         (GtkNotebook     *notebook,
                                        GtkNotebookPage *page,
                                        gint             page_num,
                                        gpointer         user_data);

void
on_protos_notebook_switch_page         (GtkNotebook     *notebook,
                                        GtkNotebookPage *page,
                                        gint             page_num,
                                        gpointer         user_data);

void
on_file_new_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_file_save_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_file_save_as_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_file_open_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_file_exit_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_ip_entry_ok_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_ip_entry_cancel_clicked             (GtkButton       *button,
                                        gpointer         user_data);


void
on_change_mono_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_font_ok_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_font_cancel_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_font_apply_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_number_spin_key_press_event         (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_number_decimal_toggled              (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_number_hex_toggled                  (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_number_ok_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_number_cancel_clicked               (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_largenumber_entry_key_press_event   (GtkWidget       *widget,
                                        GdkEventKey     *event,
					gpointer         user_data);

void
on_largenumber_ok_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_largenumber_cancel_clicked          (GtkButton       *button,
					gpointer         user_data);

void
on_largenumber_up_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_largenumber_down_clicked            (GtkButton       *button,
                                        gpointer         user_data);


void
on_capt_start_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_capt_close_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_capt_size_lim_checkbutton_toggled   (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_capt_stop_count_checkbutton_toggled (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_capt_stop_time_checkbutton_toggled  (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_capt_stop_size_checkbutton_toggled  (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_capt_filter_file_checkbutton_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_capt_filter_file_button_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_capture_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_capt_stop_button_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_apply_to_all_togglebutton_toggled   (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_capt_lim_checkbutton_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

==> netdude-0.4.0.tar.gz: netdude-0.4.0/src/callbacks.h <==
#include <gtk/gtk.h>

void
on_filesel_ok_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_filesel_cancel_clicked              (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_toplevel_delete_event               (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_confirm_yes_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_confirm_no_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_confirm_cancel_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_trace_list_select_row             (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_trace_list_row_move               (GtkCList        *clist,
                                        gint             arg1,
                                        gint             arg2,
                                        gpointer         user_data);

gboolean
on_trace_list_button_press_event     (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_trace_list_select_row             (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_trace_list_unselect_row           (GtkCList        *clist,
                                        gint             row,
                                        gint             column,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_trace_list_end_selection          (GtkCList        *clist,
                                        gpointer         user_data);

void
on_trace_list_select_all             (GtkCList        *clist,
                                        gpointer         user_data);

void
on_trace_list_unselect_all           (GtkCList        *clist,
                                        gpointer         user_data);

void
on_trace_list_size_allocate          (GtkWidget       *widget,
                                        GtkAllocation   *allocation,
                                        gpointer         user_data);

gboolean
on_trace_list_motion_notify_event    (GtkWidget       *widget,
                                        GdkEventMotion  *event,
                                        gpointer         user_data);

gboolean
on_trace_list_leave_notify_event     (GtkWidget       *widget,
                                        GdkEventCrossing *event,
                                        gpointer         user_data);

gboolean
on_trace_list_key_press_event        (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_packet_cut_activate                 (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_copy_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_paste_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_unselect_all_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_select_all_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_delete_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_menubar_button_press_event          (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_about_okay_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_preferences_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_pref_ok_clicked                     (GtkButton       *button,
                                        gpointer         user_data);

void
on_pref_cancel_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_pref_apply_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_trace_win_bar_button_release_event  (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_plugin_activate                     (gpointer         user_data,
					gint             action,
					GtkWidget       *widget);

void
on_pref_tcpdump_loc_browse_button_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_tcpdump_error_okay_button_clicked   (GtkButton       *button,
                                        gpointer         user_data);


gboolean
on_splash_window_button_press_event    (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_recent_item0_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_recent_item1_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_recent_item2_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_recent_item3_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_recent_item4_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about_plugin_activate               (gpointer         user_data,
					gint             action,
					GtkWidget       *widget);

void
on_about_proto_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_trace_close_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_trace_menu_press_event              (GtkWidget       *widget,
					GdkEventButton  *event,
					gpointer         user_data);

void
on_traces_notebook_switch_page         (GtkNotebook     *notebook,
                                        GtkNotebookPage *page,
                                        gint             page_num,
                                        gpointer         user_data);

void
on_protos_notebook_switch_page         (GtkNotebook     *notebook,
                                        GtkNotebookPage *page,
                                        gint             page_num,
                                        gpointer         user_data);

void
on_file_new_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_file_save_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_file_save_as_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_file_open_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_file_exit_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_about_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_ip_entry_ok_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_ip_entry_cancel_clicked             (GtkButton       *button,
                                        gpointer         user_data);


void
on_change_mono_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_font_ok_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_font_cancel_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_font_apply_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_number_spin_key_press_event         (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);

void
on_number_decimal_toggled              (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_number_hex_toggled                  (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_number_ok_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_number_cancel_clicked               (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_largenumber_entry_key_press_event   (GtkWidget       *widget,
                                        GdkEventKey     *event,
					gpointer         user_data);

void
on_largenumber_ok_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_largenumber_cancel_clicked          (GtkButton       *button,
					gpointer         user_data);

void
on_largenumber_up_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_largenumber_down_clicked            (GtkButton       *button,
                                        gpointer         user_data);


void
on_pref_tmpdir_browse_button_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_reload_plugins_activate             (gpointer         user_data,
					gint             action,
					GtkWidget       *widget);

void
on_apply_to_selection_activate         (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_apply_to_trace_area_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_other_trace_area_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_nav_load_button_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_nav_cancel_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_nav_type_radiobutton_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_nav_time_entries_changed            (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_nav_prev_button_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_nav_next_button_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_file_info_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_file_info_close_button_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_filter_create_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_filter_ok_button_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_filters_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_filter_modify_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_filter_delete_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_trace_filter_update_button_clicked  (GtkButton       *button,
                                        gpointer         user_data);

void
on_trace_filter_cancel_button_clicked  (GtkButton       *button,
                                        gpointer         user_data);

void
on_filtering_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_next_packet_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_previous_packet_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_next_with_same_protocol_activate    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_previous_with_same_protocol_activate
                                        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_next_selected_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_previous_selected_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_file_menu_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_edit_menu_activate                  (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_go_menu_activate                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_protocol_menu_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);



void
on_view_fixed_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_view_fixed_button_press_event       (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_packet_filter_activate              (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_packet_unfilter_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_filtered_delete_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_next_unfiltered_activate            (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_previous_unfiltered_activate        (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_ip_button_release_event             (GtkWidget       *widget,
                                        GdkEventButton  *event,
                                        gpointer         user_data);

void
on_pit_time_entries_changed            (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_view_fixed_area_button_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_trace_area_new_button_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_trace_area_del_button_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_trace_area_set_button_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_trace_area_part_button_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_trace_area_trace_button_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_trace_area_apply_button_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_trace_area_close_button_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_string_ok_button_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_string_cancel_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_area_list_select                    (GtkList         *list,
                                        GtkWidget       *widget,
                                        gpointer         user_data);

void
on_trace_area_current_button_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_trace_areas_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_netdude_output_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_libnetdude_output_activate          (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

void
on_pcapnav_output_activate             (GtkMenuItem     *menuitem,
                                        gpointer         user_data);

gboolean
on_string_entry_key_press_event        (GtkWidget       *widget,
                                        GdkEventKey     *event,
                                        gpointer         user_data);
